/*

  This file is a part of GRALEEDITOR, a program to help create input data
  for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef FITSITEM_H

#define FITSITEM_H

#include <QGraphicsItem>
#include <QObject>
#include <grale/vector2d.h>

namespace grale
{
	class FITSImage;
	class CoordinateInterface;
}

class QPixmap;

class FITSItem : public QObject, public QGraphicsItem
{
	Q_OBJECT
public:
	FITSItem(QGraphicsItem *pParent = 0);
	~FITSItem();

	bool load(const QString &fname);
	void clear();
	void setMinMax(double min, double max);
	void setCenterPoint(grale::Vector2D<double> point);

	bool isImageLoaded() const								{ if (m_pFITSImage != 0) return true; return false; }
	QString getFileName() const								{ return m_fitsFileName; }
	grale::Vector2D<double> getCenterPoint() const						{ return m_centerPoint; }
	grale::Vector2D<double> getImageCenterPoint() const					{ return m_imageCenterPoint; }
	void getMinMax(double &min, double &max) const						{ min = m_min; max = m_max; }

	QRectF boundingRect() const;
signals:
	void centerChanged();
private:
	void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
	static grale::Vector2D<double> subtractPosition(grale::Vector2D<double> point, grale::Vector2D<double> center);
	void mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event);
	void mousePressEvent(QGraphicsSceneMouseEvent *event);
	void mouseReleaseEvent(QGraphicsSceneMouseEvent *event);
	void updatePointTransforms();

	QPixmap *m_pPixmap;
	QRectF m_boundingRect;
	double m_min, m_max;

	grale::FITSImage *m_pFITSImage;
	grale::Vector2D<double> m_centerPoint, m_imageCenterPoint;
	const grale::CoordinateInterface *m_pCoordinates;
	QString m_fitsFileName;
};

#endif // FITSITEM_H

