/*

  This file is a part of GRALEEDITOR, a program to help create input data
  for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef GRALEEDITOR_H

#define GRALEEDITOR_H

#include <QMainWindow>
#include <QList>

class EditorScene;
class EditorWidget;
class QTreeWidget;
class QTreeWidgetItem;
class QAction;
class QSplitter;
class QLineEdit;

class GraleEditor : public QMainWindow
{
	Q_OBJECT
public:
	enum Tool { SelectTool, AddPointTool, CenterTool, GroupNumberTool, PointInfoTool, PointMatchTool, InvalidTool };

	GraleEditor();
	~GraleEditor();

	static GraleEditor *getInstance()							{ return m_pInstance; }
	Tool getCurrentTool() const;
public slots:
	void onAddImageLayer();
	void onAddPointsLayer();
	void onLayerItemDoubleClicked(QTreeWidgetItem *item, int column);
	void onLayerItemChanged(QTreeWidgetItem *item, int column);
	void onLayerUp();
	void onLayerDown();
	void onAddOneTriangle();
	void onTriangulate();
	void onAddGrid();
	void onImportImagesData();
	void onExportImagesData();
	void onAddView();
	void onDeleteView();
	void onToolChanged(QAction *pAction);
	bool onNew();
	void onLoad();
	void onSave();
	void onCopy();
	void onPaste();
	void onExportBitmap();
	void onAreaExportBitmap();
	void onDefaultPointSizeChanged();
	void onDefaultMatchPointSizeChanged();
	void onSetPointSize();
	void onSetMatchPointSize();
	void onOrientationChanged(QAction *pAction);
private:
	void createMenus();
	void displayActiveLayer();
	void keyPressEvent(QKeyEvent *event);
	void keyReleaseEvent(QKeyEvent *event);
	void closeEvent(QCloseEvent *event);
	void toolCheck();

	EditorScene *m_pScene;
	QTreeWidget *m_pLayersWidget;
	QAction *m_pSelectAction;
	QAction *m_pAddPointAction;
	QAction *m_pCenterAction;
	QAction *m_pGroupNumberAction;
	QAction *m_pPointInfoAction;
	QAction *m_pPointMatchTool;
	QAction *m_pActionTriangles;
	QAction *m_pActionIntensities;
	QAction *m_pActionGroups;
	QAction *m_pActionTimeDelays;
	QSplitter *m_pViewSplitter;

	QAction *m_pXLeftAction, *m_pXRightAction;
	
	QLineEdit *m_pDefaultMatchPointSizeEdit;
	QLineEdit *m_pDefaultPointSizeEdit;

	QList<EditorWidget *> m_editorWidgets;

	static GraleEditor *m_pInstance;

	QList<QPointF> m_copyPoints;
};

#endif // GRALEEDITOR_H
