/*

  This file is a part of GRALEEDITOR, a program to help create input data
  for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#include "gridinputdialog.h"
#include <QIntValidator>
#include <QDoubleValidator>

GridInputDialog::GridInputDialog(QWidget *pParent) : QDialog(pParent)
{
	setupUi(this);

	m_editXPoints->setValidator(new QIntValidator(2, 1000, this));
	m_editYPoints->setValidator(new QIntValidator(2, 1000, this));
	m_editWidth->setValidator(new QDoubleValidator(0.000001, 10000.0, 100, this));
	m_editHeight->setValidator(new QDoubleValidator(0.000001, 10000.0, 100, this));
	m_editXCenter->setValidator(new QDoubleValidator(-1000.0, 1000.0, 100, this));
	m_editYCenter->setValidator(new QDoubleValidator(-1000.0, 1000.0, 100, this));
}

GridInputDialog::~GridInputDialog()
{
}

int GridInputDialog::getXPoints() const
{
	return m_editXPoints->text().toInt();
}

int GridInputDialog::getYPoints() const
{
	return m_editYPoints->text().toInt();
}

double GridInputDialog::getXCenter() const
{
	return m_editXCenter->text().toDouble();
}

double GridInputDialog::getYCenter() const
{
	return m_editYCenter->text().toDouble();
}

double GridInputDialog::getWidth() const
{
	return m_editWidth->text().toDouble();
}

double GridInputDialog::getHeight() const
{
	return m_editHeight->text().toDouble();
}

bool GridInputDialog::getAddTriangles() const
{
	if (m_checkAddTriangles->checkState() == Qt::Checked)
		return true;
	return false;
}


