/*

  This file is a part of GRALEEDITOR, a program to help create input data
  for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef IMAGEITEM_H

#define IMAGEITEM_H

#include <QGraphicsItem>
#include <grale/vector2d.h>
#include <vector>

class QPixmap;
class FITSItem;

class ImageItem : public QGraphicsItem
{
public:
	ImageItem(QGraphicsItem *pParent = 0);
	~ImageItem();

	bool load(const QString &fname);
	void clear();
	void matchFITSItem(FITSItem *pFITSItem);
	QString getFileName() const								{ return m_imageFileName; }
private:
	QRectF boundingRect() const;
	void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
	void mousePressEvent(QGraphicsSceneMouseEvent *event);
	void mouseReleaseEvent(QGraphicsSceneMouseEvent *event);
	double findScaleFactor(const std::vector<grale::Vector2D<double> > points);
	void updatePointTransforms();

	QPixmap *m_pPixmap;
	QRectF m_boundingRect;
	QString m_imageFileName;
};

#endif // IMAGEITEM_H
