/*

  This file is a part of GRALEEDITOR, a program to help create input data
  for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#include "pointinfodialog.h"
#include <stdio.h>

PointInfoDialog::PointInfoDialog(double intensity, bool hasTimeDelay, double timeDelay, QWidget *pParent) : QDialog(pParent)
{
	setupUi(this);

	m_editIntens->setValidator(new QDoubleValidator(-1000000000.0, 1000000000.0, 100, this));
	m_editTimeDelay->setValidator(new QDoubleValidator(-1000000000.0, 1000000000.0, 100, this));

	char str[1024];

	if (hasTimeDelay)
	{
		sprintf(str, "%10.10f", timeDelay);
		m_editTimeDelay->setText(str);
		m_checkTimeDelay->setCheckState(Qt::Checked);
	}
	else
		m_checkTimeDelay->setCheckState(Qt::Unchecked);

	sprintf(str, "%10.10f", intensity);
	m_editIntens->setText(str);

}

PointInfoDialog::~PointInfoDialog()
{
}

double PointInfoDialog::getTimeDelay() const
{
	return m_editTimeDelay->text().toDouble();
}

double PointInfoDialog::getIntensity() const
{
	return m_editIntens->text().toDouble();
}

bool PointInfoDialog::hasTimeDelay() const
{
	if (m_checkTimeDelay->checkState() == Qt::Checked)
		return true;
	return false;
}

