/*

  This file is a part of GRALEEDITOR, a program to help create input data
  for gravitational lens inversion using GRALE.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef POINTITEM_H

#define POINTITEM_H

#include <QGraphicsItem>
#include <QList>

class TriangleItem;
class QGraphicsTextItem;

class PointItem : public QGraphicsItem
{
public:
	PointItem(QGraphicsItem *pParent = 0);
	~PointItem();

	void addTriangle(TriangleItem *pTriangle)				{ m_triangles.append(pTriangle); }
	void removeTriangle(TriangleItem *pTriangle)				{ m_triangles.removeAll(pTriangle); }
	void setScaleFactor(double scale);

	void setGroupNumber(int id);
	void setIntensity(double i)						{ m_intensity = i; }
	void setTimeDelay(double td);
	void clearTimeDelay();
	bool hasGroupNumber() const						{ if (m_pGroupTextItem) return true; return false; }
	bool hasTimeDelay() const						{ if (m_pTimeTextItem) return true; return false; }
	int getGroupNumber() const						{ return m_group; }
	double getIntensity() const						{ return m_intensity; }
	double getTimeDelay() const						{ return m_timeDelay; }

	QList<TriangleItem *> getTriangles()					{ return m_triangles; }
private:
	QRectF boundingRect() const;
	QPainterPath shape() const;
	void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
	QVariant itemChange(GraphicsItemChange change, const QVariant & value);
	void mousePressEvent(QGraphicsSceneMouseEvent *event);
	void mouseReleaseEvent(QGraphicsSceneMouseEvent *event);

	QList<TriangleItem *> m_triangles;

	double m_intensity;
	double m_timeDelay;
	int m_group;

	QGraphicsTextItem *m_pGroupTextItem;
	QGraphicsTextItem *m_pTimeTextItem;
};

#endif // POINTITEM_H
